<?php
/******************************* PHP-P10 v2 *****************************
 * Copyright (C) 2011-2012  Philipp Kreil (pk910)                       *
 *                                                                      *
 * This program is free software: you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation, either version 3 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                      *
 ************************************************************************
 *
 *  Uplink/P10_User.class.php
 *
 * This class represents a IRC User
 *
 */

class P10_User {
	private static $static_users = array();

	public static function getUserByNum($numeric) {
		if(array_key_exists($numeric, self::$static_users)) {
			return self::$static_users[$numeric];
		}
		return NULL;
	}

	public static function getUserByNick($nick) {
		$nick = strtolower($nick);
		foreach(self::$static_users as $user) {
			if(strtolower($user->getNick()) == $nick) {
				return $user;
			}
		}
		return NULL;
	}

	public static function getAllUsers() {
		return self::$static_users;
	}


	private $numeric;
	private $server;
	private $nick;
	private $ident;
	private $host;
	private $ip;
	private $connect_time;
	private $modes;
	private $realname;
	private $channels = array();
	private $away = null;

	public function __construct($nick, $numeric, $server, $connect_time, $ident, $host, $ip, $realname, $modes) {
		$this->nick = $nick;
		$this->numeric = $numeric;
		$this->server = $server;
		$this->connect_time = $connect_time;
		$this->ident = $ident;
		$this->host = $host;
		$this->ip = $ip;
		$this->realname = $realname;
		$this->modes = $modes;
		$server->addUser($this);
		self::$static_users[$numeric] = $this;
	}

	public function getNumeric() {
		return $this->numeric;
	}

	public function getServer() {
		return $this->server;
	}

	public function setNick($nick) {
		$this->nick = $nick;
	}

	public function getNick() {
		return $this->nick;
	}

	public function setIdent($ident) {
		$this->ident = $ident;
	}

	public function getIdent() {
		return $this->ident;
	}

	public function getHost() {
		return $this->host;
	}

	public function getIP() {
		return $this->ip;
	}

	public function getConnectTime() {
		return $this->connect_time;
	}

	public function getModes() {
		return $this->modes;
	}

	public function getRealname() {
		return $this->realname;
	}

	public function setAway($away) {
		$this->away = $away;
	}

	public function getAway() {
		return $this->away;
	}

	public function isAway() {
		return ($this->away != null);
	}

	public function quit($reason) {
		$this->server->delUser($this);
		unset(self::$static_users[$this->numeric]);
		foreach($this->channels as $channel) {
			$channel->quitUser($this);
		}
	}

	public function addChannel($channel) {
		$this->channels[strtolower($channel->getName())] = $channel;
	}

	public function delChannel($channel) {
		if(array_key_exists(strtolower($channel->getName()), $this->channels)) {
			unset($this->channels[strtolower($channel->getName())]);
		} else {
			trigger_error("Tried to remove a Channel, that does NOT exist.", E_USER_WARNING);
		}
	}

	public function getChannels() {
		return $this->channels;
	}

	public function getChannelCount() {
		return count($this->channels);
	}

	public function isOnChannel($channel) {
		return array_key_exists(strtolower($channel->getName()),$this->channels);
	}
	
	public function getAuthNick() {
		$authData = $this->getModes()->hasMode('r');
		$authnick = false;
		if($authData) {
			$authData = explode(':', $authData);
			$authnick = $authData[0];
		}
		
		return $authnick;
	}
}

?>